# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - text_plain (MoinShare)

    @copyright: 2012, 2013, 2014 by Paul Boddie <paul@boddie.org.uk>
    @license: GNU GPL (v2 or later), see COPYING.txt for details.
"""

from MoinSupport import parseAttributes

Dependencies = ["pages"]

# Parser support.

class Parser:

    "Display data in text/plain format."

    Dependencies = Dependencies
    extensions = [".txt"]

    # Input content types understood by this parser.

    input_mimetypes = ["text/plain"]

    # Output content types preferred by this parser.

    output_mimetypes = ["text/plain", "text/html"]

    def __init__(self, raw, request, **kw):

        """
        Initialise the parser with the given 'raw' data, 'request' and any
        keyword arguments that may have been supplied.
        """

        self.raw = raw
        self.request = request
        self.attrs = parseAttributes(kw.get("format_args", ""), False)

    def format(self, fmt, write=None):

        """
        Format plain text using the given formatter 'fmt'. If the 'write'
        parameter is specified, use it to write output; otherwise, write output
        using the request.
        """

        write = write or self.request.write
        write(fmt.preformatted(1))
        write(fmt.text(self.raw.expandtabs()))
        write(fmt.preformatted(0))

    # Extra API methods.

    def formatForOutputType(self, mimetype, write=None):

        """
        Format plain text for the given 'mimetype'. If the 'write' parameter is
        specified, use it to write output; otherwise, write output using the
        request.
        """

        request = self.request
        write = write or request.write
        fmt = request.html_formatter
        _ = request.getText

        if mimetype == "text/html":
            self.format(fmt, write)
        elif mimetype == "text/plain":
            write(self.raw)

    # Class methods.

    def getOutputTypes(self):
        return self.output_mimetypes

    getOutputTypes = classmethod(getOutputTypes)

# vim: tabstop=4 expandtab shiftwidth=4
